@@ -206,3 +206,9 @@ Michael R. Davis qw/perl michaelrdavis com/
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
+
+=SEE ALSO
+
+Net::GPSD
+Geo::Spline
+Geo::Ellipsoid
